<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>CustomCommandOptDlg</name>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="97"/>
        <source>Name:</source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="99"/>
        <source>Command:</source>
        <translation>Komento:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="101"/>
        <source>Shortcuts:</source>
        <translation>Pikanäppäimet:</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="112"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="113"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="213"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="219"/>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="138"/>
        <source>Add Command</source>
        <translation>Lisää komento</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="147"/>
        <source>Edit Command</source>
        <translation>Muokkaa komentoa</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="157"/>
        <source>Delete Command</source>
        <translation>Poista komento</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="178"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="180"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Lisää</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="182"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="624"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="380"/>
        <source>Please enter a name</source>
        <translation>Kirjoita nimi</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="394"/>
        <source>Please enter a command</source>
        <translation>Kirjoita komento</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="444"/>
        <source>The name already exists,</source>
        <translation>Nimi on jo olemassa.</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="445"/>
        <source>please input another one.</source>
        <translation>kirjoita toinen.</translation>
    </message>
</context>
<context>
    <name>CustomCommandPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="196"/>
        <source>Add Command</source>
        <translation>Lisää komento</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandpanel.cpp" line="200"/>
        <source>No commands yet</source>
        <translation>Ei vielä komentoja</translation>
    </message>
</context>
<context>
    <name>CustomCommandPlugin</name>
    <message>
        <location filename="../src/customcommand/customcommandplugin.cpp" line="35"/>
        <source>Custom commands</source>
        <translation>Mukautetut komennot</translation>
    </message>
</context>
<context>
    <name>CustomCommandSearchRstPanel</name>
    <message>
        <location filename="../src/customcommand/customcommandsearchrstpanel.cpp" line="132"/>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
</context>
<context>
    <name>CustomThemeSettingDialog</name>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="238"/>
        <source>Custom Theme</source>
        <translation>Mukautettu teema</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="262"/>
        <source>Style:</source>
        <translation>Tyyli:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="266"/>
        <source>Light</source>
        <translation>Vaalea</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="271"/>
        <source>Dark</source>
        <translation>Tumma</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="325"/>
        <source>Fore color:</source>
        <translation>Etuosan väri:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="332"/>
        <source>Back color:</source>
        <translation>Taustan väri:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="350"/>
        <source>Prompt PS1:</source>
        <translation>Kehote PS1:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="354"/>
        <source>Prompt PS2:</source>
        <translation>Kehote PS2:</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="424"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../src/views/customthemesettingdialog.cpp" line="431"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Vahvista</translation>
    </message>
</context>
<context>
    <name>GroupConfigOptDlg</name>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="39"/>
        <source>Group Name(Required)</source>
        <translation>Ryhmänimi (vaaditaan)</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="41"/>
        <source>Add Group</source>
        <translation>Lisää ryhmä</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="44"/>
        <source>Edit Group</source>
        <translation>Muokkaa ryhmää</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="60"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="61"/>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="61"/>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="65"/>
        <source>Please enter a group name</source>
        <translation>Kirjoita ryhmän nimi</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/groupconfigoptdlg.cpp" line="69"/>
        <source>The name should be no more than 30 characters</source>
        <translation>Nimessä saa olla enintään 30 merkkiä</translation>
    </message>
</context>
<context>
    <name>ListView</name>
    <message>
        <location filename="../src/views/listview.cpp" line="868"/>
        <source>Delete Server</source>
        <translation>Poista palvelin</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="870"/>
        <source>Delete Custom Command</source>
        <translation>Poista mukautettu komento</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="873"/>
        <source>Cancel Server Group</source>
        <translation>Peruuta palvelinryhmä</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="882"/>
        <source>Ungrouped servers will go back to server list!</source>
        <translation>Ei ryhmittellyt palvelimet palaavat palvelinlistalle!</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="498"/>
        <location filename="../src/views/listview.cpp" line="880"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Haluatko varmasti poistaa %1?</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="224"/>
        <location filename="../src/main/mainwindow.cpp" line="276"/>
        <source>New window</source>
        <translation>Uusi ikkuna</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="291"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="702"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="704"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1752"/>
        <source>Type path to download file</source>
        <translation>Kirjoita ladattavan tiedoston polku</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="2049"/>
        <source>Custom Theme</source>
        <translation>Mukautettu teema</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="17"/>
        <source>Copy on select</source>
        <translation>Kopioi valittu</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="19"/>
        <source>Cursor blink</source>
        <translation>Kursorin vilkkuminen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="21"/>
        <source>Cursor style</source>
        <translation>Kursorin tyyli</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="23"/>
        <source>Scroll on keystroke</source>
        <translation>Selaa näppäimillä</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="25"/>
        <source>Scroll on output</source>
        <translation>Selaa ulostuloa</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="27"/>
        <source>Allow Ctrl+scrollwheel to zoom text size</source>
        <translation>Salli Ctrl+rulla vaihtamaan tekstin kokoa</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="29"/>
        <source>Hide Quake window after losing focus</source>
        <translation>Piilota quake-ikkuna kadotetun tarkennuksen jälkeen</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="31"/>
        <source>Quake window animation speed</source>
        <translation>Quake-ikkunan animaation nopeus</translation>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="145"/>
        <location filename="../src/settings/settings_translation.cpp" line="33"/>
        <source>Blur background</source>
        <translation>Sumea tausta</translation>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="214"/>
        <source>debuginfod URLs</source>
        <translation>viankorjaustiedot URL</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="35"/>
        <source>Use on starting</source>
        <translation>Käyttö käynnistettäessä</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="37"/>
        <source>Font</source>
        <translation>Kirjasin</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="39"/>
        <source>Font size</source>
        <translation>Kirjasimen koko</translation>
    </message>
    <message>
        <location filename="../src/main/service.cpp" line="176"/>
        <location filename="../src/settings/settings_translation.cpp" line="41"/>
        <source>Opacity</source>
        <translation>Läpinäkyvyys</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="43"/>
        <source>Advanced</source>
        <translation>Lisäasetukset</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="45"/>
        <source>Cursor</source>
        <translation>Kursori</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="47"/>
        <source>Scroll</source>
        <translation>Vieritä</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="49"/>
        <source>Window</source>
        <translation>Ikkuna</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="51"/>
        <source>Basic</source>
        <translation>Perusasetukset</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="53"/>
        <source>Interface</source>
        <translation>Liitäntä</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="55"/>
        <source>Shortcuts</source>
        <translation>Pikanäppäimet</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1594"/>
        <location filename="../src/settings/settings_translation.cpp" line="57"/>
        <source>Others</source>
        <translation>Muut</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1592"/>
        <location filename="../src/main/mainwindow.cpp" line="2183"/>
        <location filename="../src/main/terminalapplication.cpp" line="25"/>
        <location filename="../src/settings/settings_translation.cpp" line="59"/>
        <source>Terminal</source>
        <translation>Pääte</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="61"/>
        <source>Workspace</source>
        <translation>Välilehti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="63"/>
        <source>Custom commands</source>
        <translation>Mukautetut komennot</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="65"/>
        <source>Display shortcuts</source>
        <translation>Näytä pikanäppäimet</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="67"/>
        <source>Remote management</source>
        <translation>Etähallinta</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/settings/settings_translation.cpp" line="101"/>
        <source>New tab</source>
        <translation>Uusi välilehti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/settings/settings_translation.cpp" line="103"/>
        <source>Next tab</source>
        <translation>Seuraava välilehti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/settings/settings_translation.cpp" line="105"/>
        <source>Previous tab</source>
        <translation>Edellinen välilehti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1640"/>
        <location filename="../src/settings/settings_translation.cpp" line="107"/>
        <source>Select left workspace</source>
        <translation>Valitse vasen työtila</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <location filename="../src/settings/settings_translation.cpp" line="109"/>
        <source>Select lower workspace</source>
        <translation>Valitse alempi työtila</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1640"/>
        <location filename="../src/settings/settings_translation.cpp" line="111"/>
        <source>Select right workspace</source>
        <translation>Valitse oikea työtila</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <location filename="../src/settings/settings_translation.cpp" line="113"/>
        <source>Select upper workspace</source>
        <translation>Valitse ylempi työtila</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="119"/>
        <source>Tab titles</source>
        <translation>Välilehden otsikot</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1641"/>
        <location filename="../src/settings/settings_translation.cpp" line="125"/>
        <source>Go to tab 1</source>
        <translation>Välilehteen 1</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1641"/>
        <location filename="../src/settings/settings_translation.cpp" line="127"/>
        <source>Go to tab 2</source>
        <translation>Välilehteen 2</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1641"/>
        <location filename="../src/settings/settings_translation.cpp" line="129"/>
        <source>Go to tab 3</source>
        <translation>Välilehteen 3</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1642"/>
        <location filename="../src/settings/settings_translation.cpp" line="131"/>
        <source>Go to tab 4</source>
        <translation>Välilehteen 4</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1642"/>
        <location filename="../src/settings/settings_translation.cpp" line="133"/>
        <source>Go to tab 5</source>
        <translation>Välilehteen 5</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1642"/>
        <location filename="../src/settings/settings_translation.cpp" line="135"/>
        <source>Go to tab 6</source>
        <translation>Välilehteen 6</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1643"/>
        <location filename="../src/settings/settings_translation.cpp" line="137"/>
        <source>Go to tab 7</source>
        <translation>Välilehteen 7</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1643"/>
        <location filename="../src/settings/settings_translation.cpp" line="139"/>
        <source>Go to tab 8</source>
        <translation>Välilehteen 8</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1643"/>
        <location filename="../src/settings/settings_translation.cpp" line="141"/>
        <source>Go to tab 9</source>
        <translation>Välilehteen 9</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="143"/>
        <source>Disable flow control using Ctrl+S, Ctrl+Q</source>
        <translation>Poista vuonohjaus käytöstä Ctrl+S, Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="145"/>
        <source>Shell profile</source>
        <translation>Liittymän profiili</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="147"/>
        <source>History size</source>
        <translation>Historian koko</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="149"/>
        <source>Include special character(s) in double click selections</source>
        <translation>Sisällytä erikoismerki(t) painamalla kahdesti valintoja</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="151"/>
        <source>Allow Ctrl + left mouse click to set cursor position</source>
        <translation>Salli Ctrl + hiiren vasen asettaa kohdistimen paikan</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="153"/>
        <source>The HTTP file server used for transmitting debugging information resources</source>
        <translation>HTTP-tiedostopalvelin, käytetään virhetietojen lähettämiseen</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="69"/>
        <location filename="../src/views/tabbar.cpp" line="486"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="208"/>
        <source>Rename title</source>
        <translation>Nimeä välilehti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1658"/>
        <location filename="../src/settings/settings_translation.cpp" line="71"/>
        <source>Fullscreen</source>
        <translation>Koko näyttö</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="73"/>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="75"/>
        <source>Default size</source>
        <translation>Oletuskoko</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="77"/>
        <source>Paste</source>
        <translation>Liitä</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="79"/>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="81"/>
        <source>Select all</source>
        <translation>Valitse kaikki</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="83"/>
        <source>Jump to next command</source>
        <translation>Siirry seuraavaan komentoon</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="85"/>
        <source>Jump to previous command</source>
        <translation>Siirry edelliseen komentoon</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="87"/>
        <source>Zoom in</source>
        <translation>Lähennä</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="89"/>
        <source>Zoom out</source>
        <translation>Loitonna</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="91"/>
        <source>Close other windows</source>
        <translation>Sulje paneelit</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1640"/>
        <location filename="../src/settings/settings_translation.cpp" line="93"/>
        <location filename="../src/views/termwidget.cpp" line="499"/>
        <source>Close other workspaces</source>
        <translation>Sulje muut työtilat</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1247"/>
        <source>Could not find &quot;%1&quot;, starting &quot;%2&quot; instead. Please check your shell profile.</source>
        <translation>Ei lötynyt &quot;%1&quot;, alkaa sen sijaan &quot;%2&quot;. Tarkista liittymäsi profiili.</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1253"/>
        <source>Could not open &quot;%1&quot;, unable to run it</source>
        <translation>Tiedostoa &quot;%1&quot; ei voitu avata, eikä suorittaa</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1255"/>
        <source>Could not find &quot;%1&quot;, unable to run it</source>
        <translation>Ei löytynyt &quot;%1&quot;, suoritus epäonnistui</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1298"/>
        <source>Output has been suspended by pressing Ctrl+S. Pressing Ctrl+Q to resume.</source>
        <translation>Tulostus on keskeytetty yhdistelmällä Ctrl+S. Jatka painamalla Ctrl+Q.</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="95"/>
        <source>Close window</source>
        <translation>Sulje paneeli</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1640"/>
        <location filename="../src/settings/settings_translation.cpp" line="97"/>
        <location filename="../src/views/termwidget.cpp" line="496"/>
        <source>Close workspace</source>
        <translation>Sulje välilehti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <location filename="../src/settings/settings_translation.cpp" line="99"/>
        <source>Horizontal split</source>
        <translation>Vaakasuora jako</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <location filename="../src/settings/settings_translation.cpp" line="115"/>
        <source>Vertical split</source>
        <translation>Pystysuora jako</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1623"/>
        <location filename="../src/settings/settings_translation.cpp" line="117"/>
        <source>Find</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="263"/>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="627"/>
        <location filename="../src/main/service.cpp" line="416"/>
        <source>please set another one.</source>
        <translation>aseta toinen.</translation>
    </message>
    <message>
        <location filename="../src/main/terminalapplication.cpp" line="28"/>
        <source>Terminal is an advanced terminal emulator with workspace, multiple windows, remote management, quake mode and other features.</source>
        <translation>Pääte on terminal-emulaattori, joka sisältää välilehdet, useita ikkunoita, etäyhteyden, quake-tilan ja useita muita ominaisuuksia.</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1590"/>
        <source>Tabs</source>
        <translation>Välilehdet</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/views/tabbar.cpp" line="480"/>
        <source>Close tab</source>
        <translation>Sulje välilehti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1639"/>
        <source>Select tab</source>
        <translation>Valitse välilehti</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1610"/>
        <source>Switch focus to &quot;+&quot; icon</source>
        <translation>Vaihda kohdistus &quot;+&quot; kuvakkeeseen</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="157"/>
        <location filename="../src/main/mainwindow.cpp" line="1698"/>
        <source>Select file to upload</source>
        <translation>Valitse lähetettävä tiedosto</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="162"/>
        <location filename="../src/main/mainwindow.cpp" line="1705"/>
        <source>Upload</source>
        <translation>Lähetä</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="230"/>
        <source>Programs are still running in terminal</source>
        <translation>Ohjelmia on silti käynnissä päätteessä</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="182"/>
        <location filename="../src/common/utils.cpp" line="216"/>
        <source>Close this terminal?</source>
        <translation>Sulje tämä pääte?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="183"/>
        <location filename="../src/common/utils.cpp" line="217"/>
        <source>There is still a process running in this terminal. Closing the terminal will terminate it.</source>
        <translation>Tässä päätteessä on vielä prosessi käynnissä. Sulkeminen lopettaa sen.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="187"/>
        <location filename="../src/common/utils.cpp" line="221"/>
        <source>There are still %1 processes running in this terminal. Closing the terminal will terminate all of them.</source>
        <translation>Tässä päätteessä on vielä %1 prosessia käynnissä. Sulkeminen lopettaa ne.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="192"/>
        <location filename="../src/common/utils.cpp" line="212"/>
        <source>Close this window?</source>
        <translation>Sulje tämä ikkuna?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="193"/>
        <location filename="../src/common/utils.cpp" line="213"/>
        <source>There are still processes running in this window. Closing the window will terminate all of them.</source>
        <translation>Tässä ikkunassa on edelleen käynnissä prosesseja. Ikkunan sulkeminen tappaa ne kaikki.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="136"/>
        <location filename="../src/main/mainwindow.cpp" line="1768"/>
        <source>Select a directory to save the file</source>
        <translation>Valitse kansio, johon tiedosto tallennetaan</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="230"/>
        <source>Are you sure you want to uninstall it?</source>
        <translation>Haluatko varmasti poistaa sen asennuksen?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="243"/>
        <location filename="../src/common/utils.cpp" line="247"/>
        <source>Are you sure you want to uninstall this application?</source>
        <translation>Haluatko varmasti poistaa tämän sovelluksen asennuksen?</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="244"/>
        <location filename="../src/common/utils.cpp" line="248"/>
        <source>You will not be able to use Terminal any longer.</source>
        <translation>Et voi enää jatkaa päätteen käyttöä.</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="253"/>
        <location filename="../src/views/listview.cpp" line="499"/>
        <location filename="../src/views/listview.cpp" line="893"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="241"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="254"/>
        <location filename="../src/common/utils.cpp" line="298"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="338"/>
        <source>Execute a command in the terminal</source>
        <translation>Suorita komento päätteessä</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="341"/>
        <source>Run script string in the terminal</source>
        <translation>Suorita komentosarja päätteessä</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="332"/>
        <source>Set the work directory</source>
        <translation>Aseta työhakemisto</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="335"/>
        <source>Set the window mode on starting</source>
        <translation>Ikkunatila käynnistyessä</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="344"/>
        <source>Run in quake mode</source>
        <translation>Suorita quake-tilassa</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="347"/>
        <source>Keep terminal open when command finishes</source>
        <translation>Pidä pääte auki, kun komento on valmis</translation>
    </message>
    <message>
        <location filename="../src/customcommand/customcommandoptdlg.cpp" line="387"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="476"/>
        <source>The name should be no more than 32 characters</source>
        <translation>Nimessä saa olla enintään 32 merkkiä</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="142"/>
        <location filename="../src/main/mainwindow.cpp" line="1774"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="546"/>
        <source>Select</source>
        <translation>Valitse</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="542"/>
        <source>Select the private key file</source>
        <translation>Valitse yksityinen avaintiedosto</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="121"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="111"/>
        <source>Tab title format</source>
        <translation>Välilehden otsikon muoto</translation>
    </message>
    <message>
        <location filename="../src/settings/settings_translation.cpp" line="123"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="113"/>
        <source>Remote tab title format</source>
        <translation>Etävälilehden otsikon muoto</translation>
    </message>
    <message>
        <location filename="../src/main/mainwindow.cpp" line="1638"/>
        <location filename="../src/views/tabbar.cpp" line="483"/>
        <source>Close other tabs</source>
        <translation>Sulje muut välilehdet</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="894"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Poista</translation>
    </message>
    <message>
        <location filename="../src/views/listview.cpp" line="500"/>
        <location filename="../src/views/tabrenamedlg.cpp" line="245"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Vahvista</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="210"/>
        <source>Add Group</source>
        <translation>Lisää ryhmä</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="211"/>
        <source>Add Server</source>
        <translation>Lisää palvelin</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementpanel.cpp" line="215"/>
        <source>No servers yet</source>
        <translation>Ei vielä palvelimia</translation>
    </message>
</context>
<context>
    <name>RemoteManagementPlugin</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="75"/>
        <source>Remote management</source>
        <translation>Etähallinta</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/remotemanagementplugn.cpp" line="201"/>
        <source>Make sure that rz and sz commands have been installed in the server before right clicking to upload and download files.</source>
        <translation>Varmista, että rz- ja sz-komennot on asennettu palvelimelle, ennen kuin napsautat hiiren oikealla painikkeella tiedostojen lähettämistä ja lataamista.</translation>
    </message>
</context>
<context>
    <name>RemoteManagementSearchPanel</name>
    <message>
        <location filename="../src/remotemanage/remotemanagementsearchpanel.cpp" line="211"/>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
</context>
<context>
    <name>ServerConfigManager</name>
    <message>
        <location filename="../src/remotemanage/serverconfigmanager.cpp" line="87"/>
        <source>Groups</source>
        <translation>Ryhmät</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigmanager.cpp" line="88"/>
        <source>Servers</source>
        <translation>Palvelimet</translation>
    </message>
</context>
<context>
    <name>ServerConfigOptDlg</name>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="91"/>
        <source>Add Server</source>
        <translation>Lisää palvelin</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="127"/>
        <source>Server name:</source>
        <translation>Palvelimen nimi:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="129"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="139"/>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="167"/>
        <source>Required</source>
        <translation>Vaadittu</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="137"/>
        <source>Address:</source>
        <translation>Osoite:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="144"/>
        <source>Port:</source>
        <translation>Portti:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="165"/>
        <source>Username:</source>
        <translation>Käyttäjänimi:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="172"/>
        <source>Password:</source>
        <translation>Salasana:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="178"/>
        <source>Certificate:</source>
        <translation>Sertifikaatti:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="185"/>
        <source>Group:</source>
        <translation>Ryhmä:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="189"/>
        <source>No Group</source>
        <translation>Ei ryhmää</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="193"/>
        <source>Path:</source>
        <translation>Polku:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="199"/>
        <source>Command:</source>
        <translation>Komento:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="205"/>
        <source>Encoding:</source>
        <translation>Koodaus:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="211"/>
        <source>Backspace key:</source>
        <translation>Askelpalautin:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="217"/>
        <source>Delete key:</source>
        <translation>Delete-näppäin:</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="223"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="224"/>
        <source>Add</source>
        <comment>button</comment>
        <translation>Lisää</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="228"/>
        <source>Edit Server</source>
        <translation>Muokkaa palvelinta</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="229"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Tallenna</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="470"/>
        <source>Please enter a server name</source>
        <translation>Kirjoita palvelimen nimi</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="483"/>
        <source>Please enter an IP address</source>
        <translation>Kirjoita IP-osoite</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="488"/>
        <source>Please enter a port</source>
        <translation>Anna portti</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="494"/>
        <source>Please enter a username</source>
        <translation>Kirjoita käyttäjänimi</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="508"/>
        <source>The server name already exists,</source>
        <translation>Palvelimen nimi on jo olemassa,</translation>
    </message>
    <message>
        <location filename="../src/remotemanage/serverconfigoptdlg.cpp" line="509"/>
        <source>please input another one. </source>
        <translation>kirjoita toinen.</translation>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <location filename="../src/main/service.cpp" line="412"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/settings/settings.cpp" line="130"/>
        <source>Split screen</source>
        <translation>Jaettu näyttö</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="130"/>
        <source>Fullscreen</source>
        <translation>Koko näyttö</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="130"/>
        <source>Normal window</source>
        <translation>Normaali ikkuna</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="130"/>
        <source>Maximum</source>
        <translation>Kokoruutu</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="722"/>
        <source>Fast</source>
        <translation>Nopea</translation>
    </message>
    <message>
        <location filename="../src/settings/settings.cpp" line="726"/>
        <source>Slow</source>
        <translation>Hidas</translation>
    </message>
</context>
<context>
    <name>ShortcutManager</name>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="268"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="277"/>
        <source>The shortcut %1 is invalid, </source>
        <translation>Pikakuvake %1 ei kelpaa,</translation>
    </message>
    <message>
        <location filename="../src/settings/shortcutmanager.cpp" line="284"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="291"/>
        <location filename="../src/settings/shortcutmanager.cpp" line="297"/>
        <source>The shortcut %1 was already in use, </source>
        <translation>Pikakuvake %1 on jo käytössä,</translation>
    </message>
</context>
<context>
    <name>TabRenameWidget</name>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="42"/>
        <source>Insert</source>
        <translation>Lisää</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="74"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="88"/>
        <source>username: %u</source>
        <translation>käyttäjänimi: %u</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="74"/>
        <source>username@: %U</source>
        <translation>käyttäjänimi@: %U</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="74"/>
        <source>remote host: %h</source>
        <translation>etäpalvelin: %h</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="75"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="87"/>
        <source>session number: %#</source>
        <translation>istunnon numero: %#</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="75"/>
        <location filename="../src/views/tabrenamewidget.cpp" line="89"/>
        <source>title set by shell: %w</source>
        <translation>shell asettanut otsikon: %w</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="86"/>
        <source>program name: %n</source>
        <translation>ohjelman nimi: %n</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="86"/>
        <source>current directory (short): %d</source>
        <translation>nykyinen hakemisto (lyhyt): %d</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="87"/>
        <source>current directory (long): %D</source>
        <translation>nykyinen hakemisto (pitkä): %D</translation>
    </message>
    <message>
        <location filename="../src/views/tabrenamewidget.cpp" line="88"/>
        <source>local host: %h</source>
        <translation>paikallinen palvelin: %h</translation>
    </message>
</context>
<context>
    <name>TermWidget</name>
    <message>
        <location filename="../src/views/termwidget.cpp" line="469"/>
        <source>Copy</source>
        <translation>Kopioi</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="472"/>
        <source>Paste</source>
        <translation>Liitä</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="481"/>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="485"/>
        <source>Open in file manager</source>
        <translation>Avaa tiedostonhallinnassa</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="490"/>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>Horizontal split</source>
        <translation>Vaakasuora jako</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="492"/>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>Vertical split</source>
        <translation>Pystysuora jako</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="503"/>
        <location filename="../src/views/termwidget.cpp" line="549"/>
        <source>New tab</source>
        <translation>Uusi välilehti</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="510"/>
        <source>Exit fullscreen</source>
        <translation>Poistu koko näytöstä</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="512"/>
        <source>Fullscreen</source>
        <translation>Koko näyttö</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="515"/>
        <source>Find</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="519"/>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="529"/>
        <source>Encoding</source>
        <translation>Koodaus</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="531"/>
        <source>Custom commands</source>
        <translation>Mukautetut komennot</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="533"/>
        <source>Remote management</source>
        <translation>Etähallinta</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="537"/>
        <source>Upload file</source>
        <translation>Lähetä tiedosto</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="538"/>
        <source>Download file</source>
        <translation>Lataa tiedosto</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="543"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../src/views/termwidget.cpp" line="1200"/>
        <source>The debuginfod settings will be effective after restart</source>
        <translation>Debuginfod-asetukset tulevat voimaan käynnistyksen jälkeen</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/common/utils.cpp" line="198"/>
        <location filename="../src/common/utils.cpp" line="232"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="200"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../src/common/utils.cpp" line="233"/>
        <location filename="../src/common/utils.cpp" line="265"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
</TS>